@@ -18,7 +18,7 @@ fn generate_self_schema() {
     if !output.status.success() {
         let stdout = from_utf8(&output.stdout).unwrap();
         let stderr = from_utf8(&output.stderr).unwrap();
-        eprint!("{}{}", stdout, stderr);
+        eprint!("{stdout}{stderr}");
         panic!("generate_self_schema.py failed with {}", output.status);
     }
 }
