@@ -3,11 +3,15 @@ from ._pydantic_core import (
     PydanticCustomError,
     PydanticKnownError,
     PydanticOmit,
+    PydanticSerializationError,
+    PydanticSerializationUnexpectedValue,
     SchemaError,
+    SchemaSerializer,
     SchemaValidator,
     Url,
     ValidationError,
     __version__,
+    to_json,
 )
 from .core_schema import CoreConfig, CoreSchema
 
@@ -16,6 +20,7 @@ __all__ = (
     'CoreConfig',
     'CoreSchema',
     'SchemaValidator',
+    'SchemaSerializer',
     'Url',
     'MultiHostUrl',
     'SchemaError',
@@ -23,4 +28,7 @@ __all__ = (
     'PydanticCustomError',
     'PydanticKnownError',
     'PydanticOmit',
+    'PydanticSerializationError',
+    'PydanticSerializationUnexpectedValue',
+    'to_json',
 )
