@@ -47,7 +47,7 @@ class TestBenchmarkSimpleModel:
 
         return SchemaValidator(
             {
-                'type': 'new-class',
+                'type': 'model',
                 'cls': CoreModel,
                 'schema': {
                     'type': 'typed-dict',
@@ -75,7 +75,7 @@ class TestBenchmarkSimpleModel:
 
         return SchemaValidator(
             {
-                'type': 'new-class',
+                'type': 'model',
                 'cls': CoreModel,
                 'schema': {
                     'type': 'typed-dict',
@@ -139,6 +139,49 @@ class TestBenchmarkSimpleModel:
         benchmark(core_validator_not_fs.validate_json, json_data)
 
 
+class TestModelLarge:
+    @pytest.fixture(scope='class')
+    def core_model_validator(self):
+        class CoreModel:
+            __slots__ = '__dict__', '__fields_set__'
+
+        return SchemaValidator(
+            {
+                'type': 'model',
+                'cls': CoreModel,
+                'schema': {
+                    'type': 'typed-dict',
+                    'return_fields_set': True,
+                    'extra_behavior': 'allow',
+                    'total': False,
+                    'fields': {f'field_{i}': {'schema': {'type': 'int'}} for i in range(100)},
+                },
+            }
+        )
+
+    data = {f'field_{97 - i}': i for i in range(98)}
+    data['more'] = 'more data'
+
+    @pytest.mark.benchmark(group='large model - python')
+    def test_core_python(self, core_model_validator, benchmark):
+        m = core_model_validator.validate_python(self.data)
+        assert m.field_0 == 97
+        assert m.field_1 == 96
+        assert m.field_97 == 0
+        assert m.more == 'more data'
+        benchmark(core_model_validator.validate_python, self.data)
+
+    @pytest.mark.benchmark(group='large model - JSON')
+    def test_core_json_fs(self, core_model_validator, benchmark):
+        json_data = json.dumps(self.data)
+        m = core_model_validator.validate_json(json_data)
+        assert m.field_0 == 97
+        assert m.field_1 == 96
+        assert m.field_97 == 0
+        assert m.more == 'more data'
+        benchmark(core_model_validator.validate_json, json_data)
+
+
 bool_cases = [True, False, 0, 1, '0', '1', 'true', 'false', 'True', 'False']
 
 
@@ -198,7 +241,7 @@ def test_small_class_core_model(benchmark):
 
     model_schema_validator = SchemaValidator(
         {
-            'type': 'new-class',
+            'type': 'model',
             'cls': MyCoreModel,
             'schema': {
                 'type': 'typed-dict',
@@ -212,7 +255,7 @@ def test_small_class_core_model(benchmark):
 
 @pytest.mark.benchmark(group='string')
 def test_core_string_lax(benchmark):
-    validator = SchemaValidator(core_schema.string_schema())
+    validator = SchemaValidator(core_schema.str_schema())
     input_str = 'Hello ' * 20
 
     assert validator.validate_python(input_str) == input_str
@@ -222,7 +265,7 @@ def test_core_string_lax(benchmark):
 
 @pytest.mark.benchmark(group='string')
 def test_core_string_strict(benchmark):
-    validator = SchemaValidator(core_schema.string_schema(strict=True))
+    validator = SchemaValidator(core_schema.str_schema(strict=True))
     input_str = 'Hello ' * 20
 
     assert validator.validate_python(input_str) == input_str
@@ -247,7 +290,7 @@ def recursive_model_data():
 def test_recursive_model_pyd(recursive_model_data, benchmark):
     class PydanticBranch(BaseModel):
         width: int
-        branch: Optional['PydanticBranch'] = None  # noqa: F821
+        branch: Optional['PydanticBranch'] = None
 
     benchmark(PydanticBranch.parse_obj, recursive_model_data)
 
@@ -262,7 +305,7 @@ def test_recursive_model_core(recursive_model_data, benchmark):
     v = SchemaValidator(
         {
             'ref': 'Branch',
-            'type': 'new-class',
+            'type': 'model',
             'cls': CoreBranch,
             'schema': {
                 'type': 'typed-dict',
@@ -544,7 +587,7 @@ def test_many_models_core_model(benchmark):
         {
             'type': 'list',
             'items_schema': {
-                'type': 'new-class',
+                'type': 'model',
                 'cls': MyCoreModel,
                 'schema': {
                     'type': 'typed-dict',
@@ -610,7 +653,7 @@ class TestBenchmarkDateTime:
 
         return SchemaValidator(
             {
-                'type': 'new-class',
+                'type': 'model',
                 'cls': CoreModel,
                 'schema': {
                     'type': 'typed-dict',
