@@ -3,8 +3,8 @@ from __future__ import annotations as _annotations
 from datetime import date, datetime, time
 from typing import Any
 
-from pydantic_core import PydanticKnownError, SchemaError, SchemaValidator
-from pydantic_core.core_schema import CoreConfig, CoreSchema, function_plain_schema
+from pydantic_core import PydanticKnownError, SchemaError, SchemaSerializer, SchemaValidator, core_schema
+from pydantic_core.core_schema import CoreConfig, CoreSchema
 
 
 class Foo:
@@ -64,17 +64,18 @@ def test_schema_typing() -> None:
     schema: CoreSchema = {'type': 'dict', 'keys_schema': {'type': 'str'}, 'values_schema': {'type': 'any'}}
     SchemaValidator(schema)
     schema: CoreSchema = {
-        'type': 'new-class',
+        'type': 'model',
         'cls': Foo,
         'schema': {'type': 'typed-dict', 'return_fields_set': True, 'fields': {'bar': {'schema': {'type': 'str'}}}},
     }
     SchemaValidator(schema)
-    schema: CoreSchema = {
+    # waiting for https://github.com/microsoft/pyright/issues/4313 to be fixed
+    schema: CoreSchema = {  # type: ignore
         'type': 'typed-dict',
         'fields': {
             'a': {'schema': {'type': 'str'}},
-            'b': {'schema': {'type': 'str'}, 'alias': 'foobar'},
-            'c': {'schema': {'type': 'str'}, 'alias': [['foobar', 0, 'bar'], ['foo']]},
+            'b': {'schema': {'type': 'str'}, 'validation_alias': 'foobar'},
+            'c': {'schema': {'type': 'str'}, 'validation_alias': [['foobar', 0, 'bar'], ['foo']]},
             'd': {'schema': {'type': 'default', 'schema': {'type': 'str'}, 'default': 'spam'}},
         },
     }
@@ -148,7 +149,7 @@ def test_correct_function_signature() -> None:
     def my_validator(value: Any, *, data: Any, config: CoreConfig | None, context: Any, **future_kwargs: Any) -> str:
         return str(value)
 
-    v = SchemaValidator(function_plain_schema(my_validator))
+    v = SchemaValidator(core_schema.function_plain_schema(my_validator))
     assert v.validate_python(1) == '1'
 
 
@@ -156,7 +157,7 @@ def test_wrong_function_signature() -> None:
     def wrong_validator(value: Any) -> Any:
         return value
 
-    v = SchemaValidator(function_plain_schema(wrong_validator))  # type: ignore
+    v = SchemaValidator(core_schema.function_plain_schema(wrong_validator))  # type: ignore
 
     # use this instead of pytest.raises since pyright complains about input when pytest isn't installed
     try:
@@ -177,3 +178,33 @@ def test_type_error():
 
     e = PydanticKnownError('recursion_loop')
     assert isinstance(e, PydanticKnownError)
+
+
+def test_ser_function_plain():
+    def f(__input: Any, __info: core_schema.SerializationInfo) -> str:
+        return str(__info)
+
+    s = SchemaSerializer(
+        core_schema.any_schema(serialization=core_schema.function_plain_ser_schema(f, json_return_type='str'))
+    )
+    assert s.to_python(123) == (
+        "SerializationInfo(include=None, exclude=None, mode='python', by_alias=True, exclude_unset=False, "
+        "exclude_defaults=False, exclude_none=False, round_trip=False)"
+    )
+
+
+def test_ser_function_wrap():
+    def f(__input: Any, __serialize: core_schema.SerializeWrapHandler, __info: core_schema.SerializationInfo) -> str:
+        return f'{__serialize} {__info}'
+
+    s = SchemaSerializer(
+        core_schema.any_schema(
+            serialization=core_schema.function_wrap_ser_schema(f, core_schema.str_schema(), when_used='json')
+        )
+    )
+    # insert_assert(s.to_python(123, mode='json'))
+    assert s.to_python(123, mode='json') == (
+        "SerializationCallable(serializer=str) "
+        "SerializationInfo(include=None, exclude=None, mode='json', by_alias=True, exclude_unset=False, "
+        "exclude_defaults=False, exclude_none=False, round_trip=False)"
+    )
