@@ -351,7 +351,7 @@ def test_datetime_future_timezone():
 
 def test_mock_utc_offset_8_hours(mocker):
     """
-    Test that mocking time.localtime() is working, note that due to caching in datetime.rs,
+    Test that mocking time.localtime() is working, note that due to caching in datetime_etc,
     time.localtime() will return `{'tm_gmtoff': 8 * 60 * 60}` for the rest of the session.
     """
     mocker.patch('time.localtime', return_value=type('time.struct_time', (), {'tm_gmtoff': 8 * 60 * 60}))
@@ -366,3 +366,36 @@ def test_mock_utc_offset_8_hours(mocker):
 def test_offset_too_large():
     with pytest.raises(SchemaError, match=r'Input should be greater than -86400 \[type=greater_than,'):
         SchemaValidator(core_schema.datetime_schema(now_op='past', now_utc_offset=-24 * 3600))
+
+
+class TestTZConstraints:
+    aware_validator = SchemaValidator(core_schema.datetime_schema(tz_constraint='aware'))
+    naive_validator = SchemaValidator(core_schema.datetime_schema(tz_constraint='naive'))
+
+    def test_raises_schema_error_for_unknown_constraint_kind(self):
+        with pytest.raises(
+            SchemaError,
+            match=(
+                r'Input should be \'aware\' or \'naive\' '
+                r'\[type=literal_error, input_value=\'foo\', input_type=str\]'
+            ),
+        ):
+            SchemaValidator({'type': 'datetime', 'tz_constraint': 'foo'})
+
+    def test_can_validate_aware_value(self):
+        value = datetime.now(tz=timezone.utc)
+        assert value is self.aware_validator.validate_python(value)
+
+    def test_raises_validation_error_when_aware_given_naive(self):
+        value = datetime.now()
+        with pytest.raises(ValidationError, match=r'Datetime should have timezone info'):
+            assert self.aware_validator.validate_python(value)
+
+    def test_can_validate_naive_value(self):
+        value = datetime.now()
+        assert value is self.naive_validator.validate_python(value)
+
+    def test_raises_validation_error_when_naive_given_aware(self):
+        value = datetime.now(tz=timezone.utc)
+        with pytest.raises(ValidationError, match=r'Datetime should not have timezone info'):
+            assert self.naive_validator.validate_python(value)
