@@ -190,11 +190,11 @@ def test_model_class():
         __slots__ = '__dict__', '__fields_set__'
         # these are here just as decoration
         width: int
-        branch: Optional['Branch']  # noqa F821
+        branch: Optional['Branch']
 
     v = SchemaValidator(
         {
-            'type': 'new-class',
+            'type': 'model',
             'ref': 'Branch',
             'cls': Branch,
             'schema': {
@@ -567,6 +567,7 @@ def test_union_cycle(strict: bool):
                     'type': 'typed-dict',
                 }
             ],
+            'auto_collapse': False,
             'strict': strict,
             'ref': 'root-schema',
             'type': 'union',
@@ -645,6 +646,7 @@ def test_function_change_id(strict: bool):
                     'schema': {'schema_ref': 'root-schema', 'type': 'recursive-ref'},
                 }
             ],
+            'auto_collapse': False,
             'strict': strict,
             'ref': 'root-schema',
             'type': 'union',
@@ -719,7 +721,7 @@ def test_error_inside_recursive_wrapper():
     )
 
 
-def test_new_class_td_recursive():
+def test_model_td_recursive():
     class Foobar:
         __slots__ = '__dict__', '__fields_set__'
 
@@ -737,7 +739,7 @@ def test_new_class_td_recursive():
                             'type': 'union',
                             'choices': [
                                 {
-                                    'type': 'new-class',
+                                    'type': 'model',
                                     'cls': Foobar,
                                     'schema': {'type': 'recursive-ref', 'schema_ref': '__main__.Foobar'},
                                 },
