@@ -2,6 +2,8 @@ import pytest
 
 from pydantic_core import SchemaError, SchemaValidator, ValidationError
 
+from ..conftest import plain_repr
+
 
 @pytest.mark.parametrize(
     'input_value,expected_value',
@@ -57,7 +59,7 @@ class TestModelClass:
                 'type': 'union',
                 'choices': [
                     {
-                        'type': 'new-class',
+                        'type': 'model',
                         'cls': self.ModelA,
                         'schema': {
                             'type': 'typed-dict',
@@ -66,7 +68,7 @@ class TestModelClass:
                         },
                     },
                     {
-                        'type': 'new-class',
+                        'type': 'model',
                         'cls': self.ModelB,
                         'schema': {
                             'type': 'typed-dict',
@@ -121,7 +123,7 @@ class TestModelClassSimilar:
                 'type': 'union',
                 'choices': [
                     {
-                        'type': 'new-class',
+                        'type': 'model',
                         'cls': self.ModelA,
                         'schema': {
                             'type': 'typed-dict',
@@ -130,7 +132,7 @@ class TestModelClassSimilar:
                         },
                     },
                     {
-                        'type': 'new-class',
+                        'type': 'model',
                         'cls': self.ModelB,
                         'schema': {
                             'type': 'typed-dict',
@@ -232,6 +234,18 @@ def test_no_choices():
     )
 
 
+def test_empty_choices():
+    msg = r'Error building "union" validator:\s+SchemaError: One or more union choices required'
+    with pytest.raises(SchemaError, match=msg):
+        SchemaValidator({'type': 'union', 'choices': []})
+
+
+def test_one_choice():
+    v = SchemaValidator({'type': 'union', 'choices': [{'type': 'str'}]})
+    assert plain_repr(v) == 'SchemaValidator(name="str",validator=Str(StrValidator{strict:false}),slots=[])'
+    assert v.validate_python('hello') == 'hello'
+
+
 def test_strict_union():
     v = SchemaValidator({'type': 'union', 'strict': True, 'choices': [{'type': 'bool'}, {'type': 'int'}]})
     assert v.validate_python(1) == 1
